#!/usr/bin/perl

# $Id: strip_id.pl 776 2005-12-18 03:51:17Z isely $

#
#  Copyright (C) 2005 Mike Isely <isely@pobox.com>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

# This script edits each file listed on the command line and
# transforms all occurences of the CVS Id keyword down to its
# unexpanded form.

use strict;
use IO::File;
use IO::Dir;

# -------------------------------------------------------------------------

sub read_file {
    my $fname = shift;
    my @data;
    my $line;
    my $fh = new IO::File("<$fname")
	or die "Failed to open $fname for reading\n";

    while ($line = <$fh>) {
	chomp $line;
	push @data,$line;
    }
    return \@data;
}


sub write_file {
    my $fname = shift;
    my $data = shift;
    my $fh = new IO::File(">$fname")
	or die "Failed to open $fname for writing\n";
    my $line;

    foreach $line (@$data) {
	print $fh $line . "\n";
    }
}


sub strip_data {
    my $data = shift;
    my $cnt = scalar(@$data);
    my $idx;

    for ($idx = 0; $idx < $cnt; $idx++) {
	next if (!($data->[$idx] =~ /\$Id:.+\$/));
	$data->[$idx] =~ s/(.*)\$Id[:].+\$(.*)/$1\$Id\$$2/g;
    }

}

sub strip_file {
    my $fname = shift;
    my $data;
    $data = read_file($fname);
    strip_data($data);
    write_file($fname,$data);
}

my $fname;

foreach $fname (@ARGV) {
    print "Stripping $fname\n";
    strip_file($fname);
}
